@@ -75,16 +75,20 @@ Arnolfini.events = function ()
 	});
 	
 	//For iphone and ipad
-	document.addEventListener('touchend',function(event) {
-		if (Arnolfini.bodyclick && !$(event.target).is('.openelement, a') && !$(event.target).closest('.openelement').length) {
-			event.stopPropagation();
-			$('.openelement').fadeOut('fast');
-			$('.openelement').removeClass('openelement');
-			Arnolfini.searchopen = false;
-			Arnolfini.menuopen = false;
-			Arnolfini.bodyclick = false;
-		}
-	});
+	if (navigator.appName != "Microsoft Internet Explorer")
+	{
+		document.addEventListener('touchend',function(event) {
+			if (Arnolfini.bodyclick && !$(event.target).is('.openelement, a') && !$(event.target).closest('.openelement').length) {
+				event.stopPropagation();
+				$('.openelement').fadeOut('fast');
+				$('.openelement').removeClass('openelement');
+				Arnolfini.searchopen = false;
+				Arnolfini.menuopen = false;
+				Arnolfini.bodyclick = false;
+			}
+		});
+	}
+
 }
 
 mediaShow.buttonPrevContent = "&larr;";
