@@ -166,6 +166,12 @@ class CommonBrowserView(BrowserView):
         else:
             return event.end() < time.time()
     
+    def getCurrentTime(self):
+        """
+        Utility, returns a current DateTime object.
+        """
+        return DateTime()
+    
     def getFormattedEventDate(self, event):
         """
         Formats the start and end dates properly and marks the event as past or future
@@ -222,12 +228,6 @@ class EventView(CommonBrowserView):
     """'
      Override of media event view class.
     """
-        
-    
-class EventArchiveView(EventView):
-    """'
-    Event archive view class.
-    """
     
 class EventArchiveListingView(CommonBrowserView):
     """'
@@ -316,7 +316,7 @@ class FolderListing(CommonBrowserView):
     """'
     Override of folder_listing view
     """
-    def results(self, b_start = 0, pagesize=10, only_documented=False):
+    def results(self, batch=True, b_start = 0, pagesize=10, only_documented=False):
         results = []
         
         if self.context.portal_type  == 'Collection':
@@ -328,7 +328,10 @@ class FolderListing(CommonBrowserView):
                         final_res.append(res)
             else:
                 final_res = list(brains)
-            results = Batch(final_res, pagesize, start=b_start)
+            if batch:
+               results = Batch(final_res, pagesize, start=b_start)
+            else:
+                return final_res
         elif self.context.portal_type  == 'Folder':
             brains = self.context.getFolderContents()
             if only_documented:
@@ -338,7 +341,10 @@ class FolderListing(CommonBrowserView):
                         final_res.append(res)
             else:
                 final_res = list(brains)
-            results = Batch(final_res, pagesize, start=b_start)
+            if batch:
+                results = Batch(final_res, pagesize, start=b_start)
+            else:
+                return final_res
             
         return results
     
@@ -350,6 +356,54 @@ class FolderListing(CommonBrowserView):
         final_res = sorted(res_list, key=lambda x: getattr(x, field, False))
         
         return Batch(final_res, results.size, start=results.start)
+  
+class EventListingView(FolderListing):
+    """'
+    Event listing view class.
+    """
+    cachedResults = None
+    
+    def resultsToday(self, only_documented=False):
+        """
+        returns a result list for events that: start <= today <= end;  Reverse chronological order
+        """
+        #Cache results layzily for better performance
+        if self.cachedResults is None:
+            self.cachedResults = self.results(batch=False, only_documented=only_documented)
+        
+        res_list = []
+        today = DateTime()
+        
+        for res in self.cachedResults:
+            if res.start <= today and today <= res.end:
+                res_list.append(res)
+        
+        final_res = sorted(res_list, key=lambda x: getattr(x, "start", False), reverse=True)
+        
+        return final_res
+        
+    def resultsFuture(self , only_documented=False):
+        """
+        returns a result list for events that: today < start; Chronological order
+        """
+        #Cache results layzily for better performance
+         #Cache results layzily for better performance
+        if self.cachedResults is None:
+            self.cachedResults = self.results(batch=False, only_documented=only_documented)
+        
+        res_list = []
+        today = DateTime()
+        
+        for res in self.cachedResults:
+            if today < res.start:
+                res_list.append(res)
+        
+        #NOTE: No need to sort here since the collection is already ordered that way but it might be mor powerfull to sort anyway... for now leaving it like this for performance sake
+        #final_res = sorted(res_list, key=lambda x: getattr(x, "start", False))
+        
+        return res_list
+        
+        
     
 class SearchView(CommonBrowserView, Search):
     """
